@@ -1,7 +1,7 @@
 from .ocr import OCR
 from .htmlGenerator import HTMLGenerator
 
-class pyDoodle2Web:
+class PyDoodle2Web:
     def __init__(self, path:str, darkMode:bool = True):
         self.path = path
         self.darkMode = True
